function plots2D(Th,u,phi,V)
  fc_tools.graphics.monitors.onGrid(3,3,'figures',1:8,'covers',0.9);
  interpreter=@(x) fc_tools.graphics.interpreter(x);
  if fc_tools.comp.isOctave(),opt_interp={'interpreter','tex'};else,opt_interp={'interpreter','latex'};end

  figure(1)
  Th.plotmesh('color','LightGray')
  hold on
  figure(1) % Bug? with Matlab 2019a following command on figure(2)?!
  Th.plotmesh('d',1,'inlegend',true);
  legend('show')
  axis off,axis image
  text(-0.5,0.5,interpreter('$\Omega$'),opt_interp{:})
  title(interpreter('2D stationary heat with potential flow - domain $\Omega$'),opt_interp{:});

  figure(2)
  Th.plot(u)%,'PlotOptions',{'SpecularStrength',0.95})
  colormap(jet)
  hold on,axis off,axis image
  colorbar()
  Th.plotiso(u,'isorange',1:16,'Color','w')
  axis off;axis image
  shading interp
  title('2D stationary heat with potential flow',opt_interp{:})
  colorbar()
  set(get(colorbar(),'title'),'string',interpreter('$u$'),opt_interp{:})

  figure(3)
  Th.plotmesh('color','LightGray')
  hold on,axis off;axis image
  Th.plotmesh('d',1,'color','k','LineWidth',2)
  colormap(jet)
  Th.plotiso(u,'niso',25,'isocolorbar',true,'format','%2.3f')
  title('2D stationary heat with potential flow',opt_interp{:})

  figure(4)
  Th.plot(phi)
  hold on,axis off,axis image
  Th.plotiso(phi,'Color','w')
  shading interp
  colorbar()
  title(interpreter('Velocity potential $\phi$'),opt_interp{:})
  set(get(colorbar(),'title'),'string',interpreter('$\phi$'),opt_interp{:})

  figure(5)
  Th.plotmesh('color','LightGray')
  hold on,axis off;axis image
  Th.plotmesh('d',1,'color','k','LineWidth',2)
  Th.plotiso(phi,'niso',25,'isocolorbar',true,'format','%2.3f','plane',true)
  title('Velocity potential $\phi$',opt_interp{:})


  v2=sqrt(V{1}.^2+V{2}.^2);
  figure(6)
  Th.plot(v2)
  hold on,axis off,axis image
  Th.plotiso(v2,'niso',15,'Color','w')
  shading interp
  colorbar()
  title('Potential flow',opt_interp{:})
  set(get(colorbar(),'title'),'string',interpreter('$\| \mathbf{V} \|_2$'),opt_interp{:})

  mv2=max(v2);
  figure(7)
  clf
  colormap(jet)
  Th.plotquiver([V{1},V{2}],'colordata',u,'scale',5*Th.get_h()/mv2,'freq',10);
  hold on,axis image, axis off
  colorbar()
  Th.plotmesh('d',1,'color','k','Linewidth',2)
  title(interpreter('Potential flow $\mathbf{V}$ colorized with heat $u$'),opt_interp{:})
  set(get(colorbar(),'title'),'string',interpreter('$u$'),opt_interp{:})

  figure(8)
  colormap(jet)
  Th.plotquiver([V{1},V{2}],'colordata',u,'scale',4*Th.get_h()/mv2,'freq',3);
  hold on,axis image, axis off
  %colorbar()
  Th.plotmesh('d',1,'color','k','Linewidth',2)
  %title(interpreter('Potential flow $\mathbf{V}$ colorized with heat $u$ (zoom)'),opt_interp{:})
  %set(get(colorbar(),'title'),'string',interpreter('$u$'),opt_interp{:})
  if fc_tools.comp.isOctave
    axis([-1   -0.14   -0.45    0.4])
  else
    camdolly(-0.4,0,0)
    camzoom(6)
  end
end
